@@ -181,7 +181,7 @@ class _CreateLoadQuantiles(DoFn):
     def process(self, data):
 
         # Put into dataframe
-        df = pd.DataFrame(data)
+        df = pd.DataFrame(list(data))
         load_quantile_df = get_load_quantiles()
         weight_quantile = []
         weight_p50 = []
